@@ -16,6 +16,28 @@
 #include "math-window.h"
 #include "utility.h"
 
+// gtk3 hack
+#if !GTK_CHECK_VERSION (3, 0, 0)
+
+	#ifndef GDK_KEY_F1
+		#define GDK_KEY_F1 GDK_F1
+	#endif
+
+	#ifndef GDK_KEY_W
+		#define GDK_KEY_W GDK_w
+	#endif
+
+	#ifndef GDK_KEY_Z
+		#define GDK_KEY_Z GDK_z
+	#endif
+
+#else // gtk 3.0.0
+
+	#define gtk_vbox_new(x,y) \
+		gtk_box_new(GTK_ORIENTATION_VERTICAL, y)
+
+#endif
+
 enum {
     PROP_0,
     PROP_EQUATION
@@ -189,7 +211,7 @@ static void help_cb(GtkWidget *widget, MathWindow *window)
     GError *error = NULL;
 
     screen = gtk_widget_get_screen(GTK_WIDGET(window));
-    gtk_show_uri(screen, "ghelp:mate-calc", gtk_get_current_event_time(), &error);
+    gtk_show_uri(screen, "help:mate-calc", gtk_get_current_event_time(), &error);
 
     if (error != NULL)
     {
@@ -200,7 +222,7 @@ static void help_cb(GtkWidget *widget, MathWindow *window)
         d = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", message);
         gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(d), "%s", error->message);
-        g_signal_connect(d, "respones", G_CALLBACK(gtk_widget_destroy), NULL);
+        g_signal_connect(d, "response", G_CALLBACK(gtk_widget_destroy), NULL);
         gtk_window_present(GTK_WINDOW (d));
 
         g_error_free(error);
@@ -371,14 +393,14 @@ static void create_menu(MathWindow* window)
     add_menu_item(menu, gtk_image_menu_item_new_from_stock(GTK_STOCK_COPY, accel_group), G_CALLBACK(copy_cb), window);
     add_menu_item(menu, gtk_image_menu_item_new_from_stock(GTK_STOCK_PASTE, accel_group), G_CALLBACK(paste_cb), window);
     menu_item = add_menu_item(menu, gtk_image_menu_item_new_from_stock(GTK_STOCK_UNDO, accel_group), G_CALLBACK(undo_cb), window);
-    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_z, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_KEY_Z, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
     menu_item = add_menu_item(menu, gtk_image_menu_item_new_from_stock(GTK_STOCK_REDO, accel_group), G_CALLBACK(redo_cb), window);
-    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_z, GDK_CONTROL_MASK | GDK_SHIFT_MASK, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_KEY_Z, GDK_CONTROL_MASK | GDK_SHIFT_MASK, GTK_ACCEL_VISIBLE);
     add_menu_item(menu, gtk_separator_menu_item_new(), NULL, NULL);
     add_menu_item(menu, gtk_image_menu_item_new_from_stock(GTK_STOCK_PREFERENCES, accel_group), G_CALLBACK(show_preferences_cb), window);
     add_menu_item(menu, gtk_separator_menu_item_new(), NULL, NULL);
     menu_item = add_menu_item(menu, gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, accel_group), G_CALLBACK(quit_cb), window);
-    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_w, GDK_CONTROL_MASK, 0);
+    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_KEY_W, GDK_CONTROL_MASK, 0);
 
     menu = add_menu(window->priv->menu_bar, MODE_MENU_LABEL);
     window->priv->mode_basic_menu_item = add_menu_item(menu, radio_menu_item_new(&group, MODE_BASIC_LABEL), G_CALLBACK(mode_changed_cb), window);
@@ -392,7 +414,7 @@ static void create_menu(MathWindow* window)
 
     menu = add_menu(window->priv->menu_bar, HELP_MENU_LABEL);
     menu_item = add_menu_item(menu, gtk_menu_item_new_with_mnemonic(HELP_CONTENTS_LABEL), G_CALLBACK(help_cb), window);
-    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_F1, 0, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(menu_item, "activate", accel_group, GDK_KEY_F1, 0, GTK_ACCEL_VISIBLE);
     add_menu_item(menu, gtk_image_menu_item_new_from_stock(GTK_STOCK_ABOUT, accel_group), G_CALLBACK(about_cb), window);
 }
 
@@ -516,6 +538,7 @@ math_window_init(MathWindow *window)
     gtk_window_set_title(GTK_WINDOW(window),
                          /* Title of main window */
                          _("Calculator"));
+    gtk_window_set_icon_name(GTK_WINDOW(window), "accessories-calculator");
     gtk_window_set_role(GTK_WINDOW(window), "mate-calc");
     gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
     g_signal_connect_after(G_OBJECT(window), "key-press-event", G_CALLBACK(key_press_cb), NULL);
